bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 12. Aventiure
___________________________________________________ #### <Wie Gvnther Sifriden zvo der hohzit bat>
| ### o dahte ovch alle zite daz Gunthers wip ### wie treit also hohe vro Kriemhilt den lip ### nv ist doch vnser eigen Sifrit der man ### er hat vns nv lange lucel dienste getan
###### 668 | ### Daz truoch si in ir herzen vnd wart ovch wol verdeit ### daz si ir vremde waren daz was ir harte leit ### daz man ir so selten diende siniv lant ### wa von daz were daz hete si gerne bechant
###### 669 | ### Si versuohte an den kvnich ob daz mohte geschehen ### daz si Kriemhilde solde noch gesehen ### si reite ez heimeliche des si da hete mvot ### do duhte den herren div rede mazlichen guot
###### 670 | ### Wie mohten wir si bringen sprach der kvnich rich ### her zvo disem lande daz wer vnmvgelich ### si sicent vns ce verre ich getarses niht gebiten ### do sprach div vrovwe in vil hochuerten siten
###### 671 | ### swie hohe riche were deheins kvniges man ### swaz im gebute sin herre daz sold er doch niht lan ### des ersmielte Gvnther do si daz gesprach ### er iachs im niht ce dienste swie diche er Syfriden sach
###### 672 | ### Si sprach lieber herre dvrch den willen min ### hilf mir daz Sifrit vnde div swester din ### komen zuo dem lande daz wir si hie gesehen [28a] ### so kvnde mir ze ware nimer lieber geschehen
###### 673 | ### Diner swester zvht vnd ir wol gezogen mvot ### so ich daran gedenke wie samphte mir daz tuot ### wie wir ensament sazen do ich wart din wip ### si mac mit eren minnen des kuenen Sifrides lip
###### 674 | ### Si gertes also lange vnze der kvnich sprach ### nv wizzet daz ich geste so gerne nie gesach ### ir mvget mich samfte vlegen ich wil die boten min ### nach in beiden senden da si here komen an den Rin
###### 675 | ### Do sprach div kvniginne so sult ir mir sagen ### wenne ir si welt besenden oder in welhen tagen ### vnser liebe vrivnde svlen komen in daz lant ### die ier dar welt senden lat werden mir bekant
###### 676 | ### Daz tuon ich sprach der furste drizech miner man ### wil ich dar lan riten die hiez er fvr sich gan ### bi den enboter mere in Sifrides lant ### ze liebe gap in Prvnhilt vil harte herlich gewant
###### 677 | ### Do sprach der kvnich Gvnther ir reken svlt von mir gesagen ### daz ich dar enbiete des svlt ir niht verdagen ### den starken Sifride vnd der swester min ### daz in darf zer werlde niemer holder sin
###### 678 | ### Vnde bitet daz si beidiv vns komen an den Rin ### daz wil ich vnd min vrowe immer diende sin ### vor disen svnwenden sol er vnde sine man ### sehen hie vil manigen der in grozer eren gan
###### 679 | ### Dem kvnich Sigmvnde saget den dienst min ### daz ich vnd mine frivnde im immer wege sin ### vnd saget ovch miner swester daz si niht laze daz ### sin rite zuo ir frivnden ir zeme nie hochzite baz
###### 680 | ### Prunhilt vnde vote vnd swaz man vrowen da vant ### die enbvten ir dienst in Sifrides lant ### den minneclichen vrowen vnd manigem kuenen man ### mit des kvniges rate die boten huoben sich dan
###### 681 | ### Si fuoren reisliche ir pferit vnd ir gewant ### daz was in do komen do rvmten si daz lant ### in zogte wol ir verte dar si da wolden varn ### der kvnich mit gewalte hiez die bote wol bewarn
###### 682 | ### < i> chomen in drin wochen geriten in daz lant ### ze Niblvnges burge dar waren si gesant ### ze Norwege in der marke funden si den degen ### ros vnd lute waren muode von den langen wegen
###### 683 | ### Sifride vnd Kriemhilde wart beiden do geseit ### daz riter komen weren die truogen solhiv kleit ### sam man ze Burgonden do der site pflac ### si spranch von einem bette da si rowende lac
###### 684 | ### Do bat si zeime venster eine maget gan ### div sach den kuenen Geren an dem hove stan ### in vnd die gesellen die waren dar gesant ### gegen ir herzeleide wie liebiv mere si bevant
###### 685 | ### Si sprach zvo dem kvnige sehet ir wa si stent [28b] ### die mit dem starken Geren vf dem hove gent ### die vns min bruoder Gvnther sendet nider Rin ### do sprach der starke Sifrit die svln vns willekomen sin
###### 686 | ### Allez daz gesinde lief da man si sach ### ir islich besvnder vil guetlich sprach ### daz beste daz si kvnden zvo den boten do ### Sigmvnt der herre was ir kunfte harte <vro>
###### 687 | ### Do wart geherberget Gere vnd sine man ### div ros man hiez behalten die boten giengen dan ### da her Sifrit bi Krimhilde saz ### in was ze hove erlovbet da von so taten si daz
###### 688 | ### Der wirt mit sime wibe stuont vf sa zehant ### wol wart enpfangen Gere vz Burgonden lant ### mit sinen hergesellen Gvnthers man ### Geren den vil riken baten an den sedel gan
###### 689 | ### Erlovbet vns die botschaft ê wir sicen gen ### vns wegemuode geste lat vns die wile sten ### wir svln iv sagen mere waz iv enboten hat ### Gvnther vnd Prunhilt der dinch vil zierlich stat
###### 690 | ### vnd waz vrov vote iwer muoter her enbot ### Giselher der ivnge vnd ovch er Gernot ### vnd iwer besten mage habent vns her gesant ### die enbietent iv ir dienst vzer Bvrgonden lant
###### 691 | ### Nv lon im got sprach Sifrit ich getruowe in wol ### triwen vnde guotes also man frivnden sol ### sam tuot ovch ir swester man sol vns mere sagen ### ob da heime vnser frivnde iht hohes muotes tragen
###### 692 | ### Sit wir von ir schieden hat man in iht getan ### minen konen magen sult ir mich wizzen lan ### daz wil ich in mit triwen immer helfen tragen ### vnz daz ir viende minen dienst muozen klagen
###### 693 | ### Do sprach der marchgraue Gere ein riter guot ### si sint in allen tvgenden so rehte hoh gemuot ### si ladent ivch ze Rine an eine hohgecit ### si sæhen iuch vil gerne daz ir des ane zwivel sit
###### 694 | ### Bittet mine frowen si svl mit iv dar komen ### swenne der winder ein ende habe genomen ### vor disen svnnewenden wolden si ivch sehen ### do sprach der starke Sifrit daz kvnde muolich gesehen
###### 695 | ### Do sprach aber Gere von Burgonden lant ### iwer muoter vote div hat ivch gemant ### Gernot vnd Giselher ir svlt in niht versagen ### daz ir in sit so verre daz hoere ich tegeliche klagen
###### 696 | ### Prunhilt min vrowe vnd ir magedin ### vrovnt sich der mere obe daz mehte sin ### daz si iuch noch sehen daz gebe in hohern muot ### do dvhten disiv mere die schoenen Kriemhilde guot
###### 697 | ### Gere was ir sippe der wirt in sicen hiez ### den gensten hiez er senken niht langer man daz hiez ### do kom ovch dar Sigmvnt da er die boten sach [29a] ### der herre friuntleich zuo den Burgonden sprach
###### 698 | ### Sit willekomen ir reken Gvnthers man ### sit daz Kriemhilde ze wibe gewan ### Sifrit min svn man soldiv diker sehen ### hie in disem lande woldet ir uns vriuntschefte iehen
###### 699 | ### Si sprachen swenne er wolden gerne komen ### in wart michel muede mit freuden benomen ### die boten bar man sicen spise man in truoch ### der hiez do geben Sifrit sinen gesten genuoch
###### 700 | ### Si muosen da beliben beuolle nivn tage ### des heten endelichen die snellen riter klage ### daz si niht wider rüten solden in ir lant ### do hete der kvnich Sifrit nach sinen frivnden gesant
###### 701 | ### Er vragte waz si rieten er sold an den Rin ### ez hat nach mir gesendet Gvnther der frivnt min ### er vnd sine mage durch ein hochcit ### nv kom ich im vil gerne an daz sin lant ce verre lit
###### 702 | ### Si bittent Kriemhilde daz si mit mir var ### nv ratet lieben frivnde wie sol si komen dar ### sold ich heruerten durch si in drizech lant ### da muose in dienen gerne hin div Sifrides hant
###### 703 | ### Do sprachen sine reken habet ir der reise muot ### hin cer hochcite wir raten waz wir <tuot> ### ir svlt min tvsent reken riten an den Rin ### so muget ir wol mit eren da cen Burgonden sin
###### 704 | ### Do sprach von Niderlanden der herre Sigmvnt ### welt ir zer hochzite wan tuot ir mir daz kvnt ### ob ez iv niht versmahet so rite ich mit iv dare ### ich fuere tusent degne da mite mer ich iwer schare
###### 705 | ### Welt ir mit vns riten lieber vater min ### sprach der kuene Sifrit vil vro sol ich des sin ### inre tagen zweluen so ruome ich miniu lant ### alle die es gerten den gap man ros vnd ovch gewant
###### 706 | ### Do der kvnich edel der reise hete muot ### do hiez man wider riten die snellen degne guot ### sinen konemagen enbot er an den Rin ### er wolde harte gerne bi ir hochgecite sin
###### 707 | ### Sifrit vnd Kriemhilt so wir hoeren sagen ### so vil den boten gaben daz ez niht mohten tragen ### ir moere haim ze lande er was ein riker man ### ir starken sovmære treip man vroelichen dan
###### 708 | ### Ir volk chleidete Sifrit vnd ovch Sigemunt ### Ekewart der graue der hiez an der stunt ### vrovwen kleider suochen die besten div man vant ### oder inner kvnde erwerben vber Sifrides lant
###### 709 | ### Die setel zuo den schilden bereiten man began ### rittern vnd vrowen die mit im solden dan ### den gap man swaz si wolden daz in niht gebrast ### er brahte sinen frivnden manigen herlichen gast
###### 710 | ### Die boten zogten sere ze lande vf den wegen [29b] ### do kom von Burgonden lant vere der <gegen> ### er wart vil wol enphangen do erbeizten si zetal ### von rossen vnd von moren fvr den Gvnthers sal
###### 711 | ### Die tvmben vnd die wisen giengen so man tuot ### vragen vmbe mere do sprach der riter guot ### swenne ich si sage den kvnige da hort irs cehant ### er gie mit den gesellen da er Gvntheren vant
###### 712 | ### Der kvnich von liebe von dem sedel spranch ### daz si so snelle komen des seite in do danch ### Provnhilt div schoene Gvnther zen boten spranch ### wie gehabet sich Sifrit von den mir liebe vil gesach
###### 713 | ### Do sprach der kuene Gere da wart er vrovden rot ### er vn iwer suester nie vriunden baz enbot ### so getriwe mere deheiner slahte man ### als iv der herre Sifrit vnd ovch sin vater hat getan
###### 714 | ### Do sprach zuo dem marchgrauen des richen kvniges wip ### saget mir kvmt vns Kriemhilt hat noch ir schoener lip ### behalten iht der zvhte der si kvnde phlegen ### si kvmet sicerlichen sprach do Gere der degen
###### 715 | ### vote bat do drate die boten fur sich gen ### man moht an ir vrage harte wol versten ### daz si horte gerne was Kriemhilt noch gesvnt ### er seite wie er si funde vnd daz si koeme in kurzer stvnt
###### 716 | ### Ez wart von in div gabe ze hove niht verdeit ### die in gap er Sifrit golt vnd ovch div kleit ### brahte man ce sehenne der drier kvnige man ### ir vil grozer milte wart da danken getan
###### 717 | ### Er mac sprach do Hagne von im sampfte geben ### er kvndez niht verswenden sold er immer leben ### hort der Niblvnge besloz hat sin hant ### hey solder immer komen in Burgonden lant
###### 718 | ### Allez daz gesinde frevte sich darzvo ### daz si komen solden spate vnde vruo ### waren vil vnmuozech der drier kvnige man ### manic hergesidele man do rihten began
###### 719 | ### Hvnolt der kuene vnd Sindolt der degen ### heten vil vnmuoze die cit si muosen pflegen ### truchsezen vnd schenchen ce rihten manige banc ### des half in ovch Ortwin des seit in Gvnther danc
###### 720 | ### Rvmolt der kvchenmeister wie wol er rihte sich ### sine vndertane <manegen> kezzel wit ### haven vnde pfannen hey waz man der da vant ### do bereite man den spise die da komen in daz lant

<<< Übersicht <<< vorige Seite nächste Seite >>>